Your message dated Sun, 06 Nov 2011 01:03:18 +0000
with message-id <[email protected]>
and subject line Bug#647578: fixed in duplicity 0.6.15-4
has caused the Debian Bug report #647578,
regarding duplicity: incremental backups are not added to chain after updating
tzdata
to be marked as done.
This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.
(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact [email protected]
immediately.)
--
647578: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=647578
Debian Bug Tracking System
Contact [email protected] with problems
--- Begin Message ---
Package: duplicity
Version: 0.6.08b-1+b1
Severity: normal
Tags: patch
Only full backups are created. When I tried to create incremental backup with
duply, everything seems fine,
but incremental backups are not added to chain. Verbose logs show error line:
> Ignoring incremental Backupset (start_time: Wed Nov 2 02:50:03 2011; needed:
> Wed Nov 2 03:50:03 2011)
The problem appeared after updating tzdata. My time zone is YEKT.
To be exact, incremental backups were created, but later on reported as
orphaned on any operation and cleaned up on CLEANUP.
Probably error was caused by tzdata update from 2011d to 2011k. Inclemental
backups created before update are still usable.
-- System Information:
Debian Release: squeeze/sid
APT prefers lucid-updates
APT policy: (500, 'lucid-updates'), (500, 'lucid-security'), (500, 'lucid')
Architecture: i386 (i686)
Kernel: Linux 2.6.32-34-generic (SMP w/4 CPU cores)
Locale: LANG=ru_RU.UTF-8, LC_CTYPE=ru_RU.UTF-8 (charmap=UTF-8)
Shell: /bin/sh linked to /bin/dash
=== modified file 'duplicity/dup_time.py'
--- duplicity/dup_time.py 2011-03-29 17:00:36 +0000
+++ duplicity/dup_time.py 2011-11-03 11:27:45 +0000
@@ -21,8 +21,7 @@
"""Provide time related exceptions and functions"""
-import time, types, re
-
+import time, types, re, calendar
from duplicity import globals
@@ -119,12 +118,20 @@
# works in terms of the current timezone and we have a
# timezone offset in the string.
timetuple = (year, month, day, hour, minute, second, -1, -1, 0)
- local_in_secs = time.mktime(timetuple)
- # mktime assumed that the tuple was a local time. Compensate
- # by subtracting the value for the current timezone.
- # We don't need to worry about DST here because we turned it
- # off in the tuple
- utc_in_secs = local_in_secs - time.timezone
+
+ if len(timestring) == 16:
+ # as said in documentation, time.gmtime() and timegm() are each others' inverse.
+ # As far as UTC format is used in new file format,
+ # do not rely on system's python DST and tzdata settings
+ # and use functions that working with UTC
+ utc_in_secs = calendar.timegm(timetuple)
+ else:
+ # mktime assumed that the tuple was a local time. Compensate
+ # by subtracting the value for the current timezone.
+ # We don't need to worry about DST here because we turned it
+ # off in the tuple
+ local_in_secs = time.mktime(timetuple)
+ utc_in_secs = local_in_secs - time.timezone
# Now apply the offset that we were given in the time string
# This gives the correct number of seconds from the epoch
# even when we're not in the same timezone that wrote the
--- End Message ---
--- Begin Message ---
Source: duplicity
Source-Version: 0.6.15-4
We believe that the bug you reported is fixed in the latest version of
duplicity, which is due to be installed in the Debian FTP archive:
duplicity_0.6.15-4.diff.gz
to main/d/duplicity/duplicity_0.6.15-4.diff.gz
duplicity_0.6.15-4.dsc
to main/d/duplicity/duplicity_0.6.15-4.dsc
duplicity_0.6.15-4_i386.deb
to main/d/duplicity/duplicity_0.6.15-4_i386.deb
A summary of the changes between this version and the previous one is
attached.
Thank you for reporting the bug, which will now be closed. If you
have further comments please address them to [email protected],
and the maintainer will reopen the bug report if appropriate.
Debian distribution maintenance software
pp.
Alexander Zangerl <[email protected]> (supplier of updated duplicity package)
(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing [email protected])
-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1
Format: 1.8
Date: Sun, 06 Nov 2011 10:44:56 +1000
Source: duplicity
Binary: duplicity
Architecture: source i386
Version: 0.6.15-4
Distribution: unstable
Urgency: low
Maintainer: Alexander Zangerl <[email protected]>
Changed-By: Alexander Zangerl <[email protected]>
Description:
duplicity - encrypted bandwidth-efficient backup
Closes: 647578
Changes:
duplicity (0.6.15-4) unstable; urgency=low
.
* applied patch for timezone confusion (closes: #647578)
Checksums-Sha1:
515ddb3dd99204611881eafbdcd005ca627df2bd 1078 duplicity_0.6.15-4.dsc
ae39177f5432cd29b83fc025f0293afc78be3e33 14728 duplicity_0.6.15-4.diff.gz
8cada8d016dccc5cca569f0383b2865d6745968c 207104 duplicity_0.6.15-4_i386.deb
Checksums-Sha256:
523662994d879ac361cbbf6b35a014c56a71a0c11c7761b70ea601a6da4ed5aa 1078
duplicity_0.6.15-4.dsc
3a2999c90f261a78a0bcc6eabdda3cd30e4c11648fb1b1debcc0b4fbb5092e22 14728
duplicity_0.6.15-4.diff.gz
75966a7806cce97e0e4fd8a41aef3578975e15787258d97c0311b908fa02c7b6 207104
duplicity_0.6.15-4_i386.deb
Files:
0148982862ba90bcf38aa6046085ab24 1078 utils optional duplicity_0.6.15-4.dsc
18d6a4e2386981fc8b671d649b359125 14728 utils optional
duplicity_0.6.15-4.diff.gz
af3c77fc71b06d062cb6ce188858d7cf 207104 utils optional
duplicity_0.6.15-4_i386.deb
-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.4.10 (GNU/Linux)
iEYEARECAAYFAk612bQACgkQpy/2bEK9ZF2OkACfYk9eCYOQz3evZFPSOt6r8UOV
8AkAoJBNzR14vGNBWArZ/K7pckfXYX/V
=NBaR
-----END PGP SIGNATURE-----
--- End Message ---